.. module:: numpy

.. _reference:

###############
NumPy reference
###############

:Release: |version|
:Date: |today|

This reference manual details functions, modules, and objects
included in NumPy, describing what they are and what they do.
For learning how to use NumPy, see the :ref:`complete documentation <numpy_docs_mainpage>`.

Python API
==========

.. toctree::
   :maxdepth: 1

   module_structure

.. toctree::
   :maxdepth: 2

   arrays

.. toctree::
   :maxdepth: 1

   ufuncs

.. toctree::
   :maxdepth: 2

   routines

.. toctree::
   :maxdepth: 1

   typing
   distutils

C API
=====

.. toctree::
   :maxdepth: 2

   c-api/index

Other topics
============

.. toctree::
   :maxdepth: 1

   array_api
   simd/index
   thread_safety
   global_state
   security
   distutils_status_migration
   distutils_guide
   swig


Acknowledgements
================

Large parts of this manual originate from Travis E. Oliphant's book
`Guide to NumPy <https://archive.org/details/NumPyBook>`__ (which generously
entered Public Domain in August 2008). The reference documentation for many of
the functions are written by numerous contributors and developers of
NumPy.
